@@ -2,13 +2,13 @@
 use strict;
 use warnings;
 
-use Net::Frame::ETH;
-use Net::Frame::IPv4;
-use Net::Frame::TCP;
+use Net::Frame::Layer::ETH;
+use Net::Frame::Layer::IPv4;
+use Net::Frame::Layer::TCP;
 
-my $eth = Net::Frame::ETH->new;
-my $ip4 = Net::Frame::IPv4->new;
-my $tcp = Net::Frame::TCP->new(
+my $eth = Net::Frame::Layer::ETH->new;
+my $ip4 = Net::Frame::Layer::IPv4->new;
+my $tcp = Net::Frame::Layer::TCP->new(
    options => "\x02\x04\x54\x0b",
 );
 
